@@ -14,7 +14,6 @@ MAX_EXAMPLES = 10
 T = tp.TypeVar("T")
 
 
-
 @hp.given(nums=st.lists(st.integers()))
 @hp.settings(max_examples=MAX_EXAMPLES)
 def test_flat_map_square(nums: tp.List[int]):
@@ -33,6 +32,7 @@ def test_flat_map_square(nums: tp.List[int]):
 
     assert nums_pl == nums_py
 
+
 @hp.given(nums=st.lists(st.integers()))
 @hp.settings(max_examples=MAX_EXAMPLES)
 def test_flat_map_square_async_1(nums: tp.List[int]):
@@ -56,6 +56,7 @@ def test_flat_map_square_async_1(nums: tp.List[int]):
 
     assert nums_pl == nums_py
 
+
 @hp.given(nums=st.lists(st.integers()))
 @hp.settings(max_examples=MAX_EXAMPLES)
 @pl.task.utils.run_test_async
@@ -80,6 +81,7 @@ async def test_flat_map_square_async_2(nums: tp.List[int]):
 
     assert nums_pl == nums_py
 
+
 @hp.given(nums=st.lists(st.integers()))
 @hp.settings(max_examples=MAX_EXAMPLES)
 @pl.task.utils.run_test_async
@@ -108,6 +110,34 @@ async def test_flat_map_square_async_3(nums: tp.List[int]):
 
     assert nums_pl == nums_py
 
+
+@hp.given(nums=st.lists(st.integers()))
+@hp.settings(max_examples=MAX_EXAMPLES)
+@pl.task.utils.run_test_async
+async def test_flat_map_square_async_4(nums: tp.List[int]):
+    def _generator(x):
+        yield x
+        yield x + 1
+        yield x + 2
+
+    async def _generator_async(x):
+        return [x, x + 1, x + 2]
+
+    async def nums_generator():
+        for x in nums:
+            yield x
+
+    nums_py = map(lambda x: x ** 2, nums)
+    nums_py = cz.mapcat(_generator, nums_py)
+    nums_py = list(nums_py)
+
+    nums_pl = pl.task.map(lambda x: x ** 2, nums_generator())
+    nums_pl = pl.task.flat_map(_generator_async, nums_pl)
+    nums_pl = await nums_pl
+
+    assert nums_pl == nums_py
+
+
 @hp.given(nums=st.lists(st.integers()))
 @hp.settings(max_examples=MAX_EXAMPLES)
 def test_flat_map_square_workers(nums: tp.List[int]):
@@ -126,6 +156,7 @@ def test_flat_map_square_workers(nums: tp.List[int]):
 
     assert sorted(nums_pl) == sorted(nums_py)
 
+
 @hp.given(nums=st.lists(st.integers()))
 @hp.settings(max_examples=MAX_EXAMPLES)
 def test_flat_map_square_workers_async_1(nums: tp.List[int]):
@@ -149,6 +180,7 @@ def test_flat_map_square_workers_async_1(nums: tp.List[int]):
 
     assert sorted(nums_pl) == sorted(nums_py)
 
+
 @hp.given(nums=st.lists(st.integers()))
 @hp.settings(max_examples=MAX_EXAMPLES)
 @pl.task.utils.run_test_async
@@ -173,6 +205,7 @@ async def test_flat_map_square_workers_async_2(nums: tp.List[int]):
 
     assert sorted(nums_pl) == sorted(nums_py)
 
+
 @hp.given(nums=st.lists(st.integers()))
 @hp.settings(max_examples=MAX_EXAMPLES)
 @pl.task.utils.run_test_async
@@ -201,6 +234,7 @@ async def test_flat_map_square_workers_async_3(nums: tp.List[int]):
 
     assert sorted(nums_pl) == sorted(nums_py)
 
+
 @hp.given(nums=st.lists(st.integers()))
 @hp.settings(max_examples=MAX_EXAMPLES)
 @pl.task.utils.run_test_async
@@ -230,6 +264,7 @@ async def test_flat_map_square_workers_async_3(nums: tp.List[int]):
 
     assert nums_py == [] or sorted(nums_pl) != sorted(nums_py)
 
+
 @hp.given(nums=st.lists(st.integers()))
 @hp.settings(max_examples=MAX_EXAMPLES)
 @pl.task.utils.run_test_async
@@ -261,6 +296,7 @@ async def test_flat_map_square_workers_async_4(nums: tp.List[int]):
 
     assert nums_py == [] or sorted(nums_pl) == sorted(nums_py)
 
+
 @hp.given(nums=st.lists(st.integers()))
 @hp.settings(max_examples=MAX_EXAMPLES)
 @pl.task.utils.run_test_async
